@@ -6,14 +6,14 @@ def ctype(text, speed = 0.1):
         time.sleep(speed)
     print()
 def clear():
-    os.system('cls' if os.name == 'nt' else 'clear')
+    os.system('cls' if os.name == 'nt' else print(f"\033c"))
 def backspace(text, speed = 0.1):
     text = str(text)
     g = len(text)
     for x in range(0, len(text)):
         print(text[0:g], end='')
         time.sleep(speed)
-        os.system('cls' if os.name == 'nt' else 'clear')
+        os.system('cls' if os.name == 'nt' else print(f"\033c"))
         g -= 1
     print()
 def pressenter():
